@@ -1,23 +1,19 @@
 
 #' @importFrom withr with_dir
 
-build_package <- function(path) {
+build_package <- function(path, tmpdir) {
 
-  path <- normalizePath(path)
-
-  tmpdir <- tempfile()
   dir.create(tmpdir)
-  on.exit(unlink(tmpdir, recursive = TRUE))
-
   file.copy(path, tmpdir, recursive = TRUE)
 
   ## If not a tar.gz, build it. Otherwise just leave it as it is.
   if (file.info(path)$isdir) {
-    with_dir(
+    build_status <- with_dir(
       tmpdir,
-      R("CMD", "build", basename(path))
+      rcmd_safe("build", basename(path))
     )
     unlink(file.path(tmpdir, basename(path)), recursive = TRUE)
+    report_system_error("Build failed", build_status)
   }
 
   ## replace previous handler, no need to clean up any more
